"use strict";

var MetadataLoader = require("./metadata-loader.js");
var MetadataRepository = require("./metadata-repository.js");
var LessTemplateLoader = require("./less-template-loader.js");
var themes = require("./themes.js");
var normalize = require("./config-normalizer");

var processTheme = function processTheme(config, metadata, version) {
    var lessTemplateLoader = new LessTemplateLoader(config, version);
    if (config.isBootstrap) {
        var bootstrapMetadata = config.bootstrapVersion === 3 ? require("../data/bootstrap-metadata/bootstrap-metadata.js") : require("../data/bootstrap-metadata/bootstrap4-metadata.js");

        return lessTemplateLoader.analyzeBootstrapTheme(config.themeName, config.colorScheme, metadata, bootstrapMetadata, config.data, config.bootstrapVersion);
    } else {
        return lessTemplateLoader.load(config.themeName, config.colorScheme, metadata, config.items);
    }
};

var buildTheme = function buildTheme(config) {
    normalize(config);
    var metadataRepository = new MetadataRepository(new MetadataLoader());
    var repositoryPromise = metadataRepository.init(themes);

    return repositoryPromise.then(function () {
        var metadata = metadataRepository.getData({
            name: config.themeName,
            colorScheme: config.colorScheme
        });

        var version = metadataRepository.getVersion();

        return processTheme(config, metadata, version);
    });
};

module.exports = {
    buildTheme: buildTheme
};